@@ -25,9 +25,6 @@
 #' missing values in the new columns created.
 #' @param verbose Toggle warnings.
 #' @param ... Not used for now.
-#' @param colnames_from Deprecated. Use `names_from` instead.
-#' @param rows_from Deprecated. Use `id_cols` instead.
-#' @param sep Deprecated. Use `names_sep` instead.
 #'
 #' @return If a tibble was provided as input, `reshape_wider()` also returns a
 #' tibble. Otherwise, it returns a data frame.
@@ -49,14 +46,14 @@
 #'        4   M     cond2        12.9")
 #'
 #'
-#' reshape_wider(
+#' data_to_wide(
 #'   data_long,
 #'   id_cols = "subject",
 #'   names_from = "condition",
 #'   values_from = "measurement"
 #' )
 #'
-#' reshape_wider(
+#' data_to_wide(
 #'   data_long,
 #'   id_cols = "subject",
 #'   names_from = "condition",
@@ -74,7 +71,7 @@
 #'
 #' production$production <- rnorm(nrow(production))
 #'
-#' reshape_wider(
+#' data_to_wide(
 #'   production,
 #'   names_from = c("product", "country"),
 #'   values_from = "production",
@@ -93,28 +90,7 @@ data_to_wide <- function(data,
                          names_glue = NULL,
                          values_fill = NULL,
                          verbose = TRUE,
-                         ...,
-                         colnames_from,
-                         rows_from,
-                         sep) {
-  if (!missing(colnames_from)) {
-    .is_deprecated("colnames_from", "names_from")
-    if (is.null(names_from)) {
-      names_from <- colnames_from
-    }
-  }
-  if (!missing(rows_from)) {
-    .is_deprecated("rows_from", "id_cols")
-    if (is.null(id_cols)) {
-      id_cols <- rows_from
-    }
-  }
-  if (!missing(sep)) {
-    .is_deprecated("sep", "names_sep")
-    if (is.null(names_sep)) {
-      names_sep <- sep
-    }
-  }
+                         ...) {
   if (is.null(id_cols)) {
     id_cols <- setdiff(names(data), c(names_from, values_from))
   }
@@ -207,7 +183,7 @@ data_to_wide <- function(data,
       rep(data[[x]][ind], times = rep_times)
     })
 
-    new_data <- data_arrange(new_data, c("temporary_id_2"))
+    new_data <- data_arrange(new_data, "temporary_id_2")
   }
 
   # don't need temporary ids anymore
@@ -218,28 +194,26 @@ data_to_wide <- function(data,
   if (!is.null(values_fill)) {
     if (length(values_fill) == 1L) {
       if (is.numeric(new_data[[values_from]])) {
-        if (!is.numeric(values_fill)) {
-          insight::format_error(paste0("`values_fill` must be of type numeric."))
-        } else {
+        if (is.numeric(values_fill)) {
           new_data <- convert_na_to(new_data, replace_num = values_fill)
+        } else {
+          insight::format_error(paste0("`values_fill` must be of type numeric."))
         }
       } else if (is.character(new_data[[values_from]])) {
-        if (!is.character(values_fill)) {
-          insight::format_error(paste0("`values_fill` must be of type character."))
-        } else {
+        if (is.character(values_fill)) {
           new_data <- convert_na_to(new_data, replace_char = values_fill)
+        } else {
+          insight::format_error(paste0("`values_fill` must be of type character."))
         }
       } else if (is.factor(new_data[[values_from]])) {
-        if (!is.factor(values_fill)) {
-          insight::format_error(paste0("`values_fill` must be of type factor."))
-        } else {
+        if (is.factor(values_fill)) {
           new_data <- convert_na_to(new_data, replace_fac = values_fill)
+        } else {
+          insight::format_error(paste0("`values_fill` must be of type factor."))
         }
       }
-    } else {
-      if (verbose) {
-        insight::format_error("`values_fill` must be of length 1.")
-      }
+    } else if (verbose) {
+      insight::format_error("`values_fill` must be of length 1.")
     }
   }
 
@@ -290,7 +264,7 @@ data_to_wide <- function(data,
 
   # convert back to date if original values were dates
   values_are_dates <- all(
-    vapply(data[, values_from, drop = FALSE], .is_date, FUN.VALUE = logical(1))
+    vapply(data[, values_from, drop = FALSE], .is_date, FUN.VALUE = logical(1L))
   )
   if (values_are_dates) {
     for (i in unstacked$col_order) {
@@ -329,7 +303,7 @@ data_to_wide <- function(data,
   # expand the values for each variable in "values_from"
   res <- list()
   for (i in seq_along(values_from)) {
-    res[[i]] <- c(tapply(x[[values_from[i]]], x$future_colnames, as.vector))
+    res[[i]] <- tapply(x[[values_from[i]]], x$future_colnames, as.vector)
     if (length(values_from) > 1L) {
       names(res[[i]]) <- paste0(values_from[i], names_sep, names(res[[i]]))
     }
@@ -342,7 +316,7 @@ data_to_wide <- function(data,
     res <- data.frame(
       matrix(
         res[[1]],
-        nrow = 1, dimnames = list(c(), names(res[[1]]))
+        nrow = 1, dimnames = list(NULL, names(res[[1]]))
       ),
       stringsAsFactors = FALSE,
       check.names = FALSE
