@@ -71,7 +71,7 @@ test_that("data_relocate select-helpers", {
 # preserve attributes --------------------------
 
 test_that("data_relocate preserves attributes", {
-  skip_if_not_or_load_if_installed("parameters")
+  skip_if_not_installed("parameters")
 
   m <- lm(Sepal.Length ~ Species, data = iris)
   out <- parameters::parameters(m)
